@@ -1,28 +1,38 @@
-
-
 test_that("registerMap", {
-  json <- jsonlite::read_json("https://echarts.apache.org/examples/data/asset/geo/USA.json")
-  dusa <- USArrests
-  dusa$states <- row.names(dusa)
+  # similar in ec.examples, with USA map
+  gjson <- jsonlite::parse_json('{"type":"FeatureCollection", "properties":{"id":"all3"},
+  "features":[
+     {"type":"Feature", "geometry":{"type":"MultiPolygon", "coordinates":[[[[2.330466,48.862223],[2.330305,48.861636],[2.329572,48.861581],[2.329466,48.861531],[2.329413,48.861528],[2.328796,48.861475],[2.328545,48.861396],[2.328466,48.861404],[2.328361,48.86137]]]]},
+    	"properties":{"lat":48.859475,"lon":2.329466,"name":"bic1","range":500, "id":"0.5 min", "ppfill": "#00FF0077"} },
+     {"type":"Feature", "geometry":{"type":"MultiPolygon", "coordinates":[[[[2.333466,48.866204],[2.333061,48.86588],[2.332897,48.865906],[2.332466,48.865801],[2.332165,48.865776],[2.331811,48.865475],[2.331621,48.86532],[2.331466,48.865265],[2.331274,48.865283]]]]},
+     	"properties":{"lat":48.859475,"lon":2.329466,"name":"bic2","range":1000, "id":"1 min"} },
+     {"type":"Feature", "geometry":{"type":"MultiPolygon", "coordinates":[[[[2.335466,48.869736],[2.335037,48.870046],[2.334836,48.870105],[2.334466,48.870265],[2.334289,48.870298],[2.333577,48.870364],[2.333466,48.870381],[2.333364,48.870373],[2.332485,48.870456]]]]},
+     	"properties": {"lat":48.859475, "lon":2.329466, "name":"bic3", "range":1500, "id":"1.5 min"} }
+  ]}')
+  ext <- function(dd) { unlist(unname(sapply(gjson$features, \(f) {f$properties[dd]}))) }
+  vals <- ext('range')
+  dparis <- data.frame(name= ext('name'), value= vals)
   p <- ec.init(preset= FALSE,
-     series= list(list(type= 'map', map= 'USA', roam= TRUE, zoom= 3, left= -100, top= -30,
-             data= lapply(ec.data(dusa, 'names'), 
-                          function(x) list(name=x$states, value=x$UrbanPop))
-     )),
-     visualMap= list(type='continuous', calculable=TRUE, 
-               inRange= list(color = rainbow(8)), seriesIndex= 0,
-               min= min(dusa$UrbanPop), max= max(dusa$UrbanPop))
+    geo= list(map= 'paris', roam= TRUE),
+    series =list(list(
+      type= 'map', geoIndex=0, coordinateSystem= 'geo',
+      data= ec.data(dparis, 'names')
+    )),
+    visualMap= list(type='continuous', calculable=TRUE,
+      inRange= list(color = rainbow(8)),
+      min= min(vals), max= max(vals))
   )
-  p$x$registerMap <- list(list(mapName= 'USA', geoJSON= json))
-  
-  expect_equal(round(p$x$registerMap[[1]]$geoJSON$features[[50]]$geometry$coordinates[[1]][[47]][[2]],4), 43.6164)
-  expect_equal(p$x$opts$series[[1]]$data[[50]]$name, 'Wyoming')
-  expect_equal(p$x$opts$series[[1]]$data[[50]]$value, 60)
+  p$x$registerMap <- list(list(mapName= 'paris', geoJSON= gjson))
+  p
+  expect_equal(length(p$x$registerMap[[1]]$geoJSON), 3)
+  expect_equal(p$x$opts$geo$map, 'paris')
+  expect_equal(p$x$opts$series[[1]]$geoIndex, 0)
+  expect_equal(p$x$opts$series[[1]]$data[[2]]$value, 1000)
 })
 
 test_that("tl.series and timeline options", {
   p <- Orange |> dplyr::group_by(age) |> ec.init(
-    tl.series=list(type='bar', encode=list(x='Tree', y='circumference'))
+    tl.series= list(type='bar', encode=list(x='Tree', y='circumference'))
   ) |> ec.upd({
     timeline <- append(timeline, list(autoPlay=TRUE))
     options <- lapply(options, 
@@ -34,6 +44,7 @@ test_that("tl.series and timeline options", {
   expect_equal(p$x$opts$timeline$data[[5]], "1231")
   expect_true(p$x$opts$dataset[[5]]$transform$config['='] == 1004)
 })
+
 test_that("tl.series type 'map'", {
 #  if (interactive()) {
     cns <- data.frame(
@@ -41,7 +52,7 @@ test_that("tl.series type 'map'", {
       value = runif(3, 1, 100)
     )
     p <- cns |> group_by(country) |> ec.init(load='world',
-        tl.series= list(type='map',  encode=list(value='value', name='country')),
+        tl.series= list(type='map', encode=list(value='value', name='country')),
         visualMap= list(calculable=TRUE, max=100)
     )
     expect_equal(p$x$opts$options[[1]]$series[[1]]$data[[1]]$name, "China")
@@ -77,7 +88,7 @@ test_that("leaflet with ec.clmn", {
 #  else expect_equal(1,1)
 })
 
-test_that("ec.data format dendrogram", {
+test_that("ec.data dendrogram", {
   hc <- hclust(dist(USArrests), "average")
   p <- ec.init(preset= FALSE,
                series= list(list(
@@ -89,14 +100,49 @@ test_that("ec.data format dendrogram", {
   expect_equal(length(p$x$opts$series[[1]]$data[[1]]$children[[1]]$children), 2)
 })
 
-test_that("ec.data format boxlpot", {
-  p <- mtcars |> dplyr::relocate(am,mpg) |> ec.data(format='boxplot')
+test_that("ec.data boxlpot", {
+  p <- mtcars |> dplyr::relocate(cyl,mpg) |> ec.data(format='boxplot')
   expect_equal(p$series[[1]]$type, 'boxplot')
-  expect_equal(p$dataset$source[[1]], c("V1","V2","V3","V4","V5","V6"))
-  expect_type(p$axlbl, 'list')  # was 'JS_EVAL'
+  expect_equal(p$dataset$source[[1]][[3]], 22.8)
+  expect_equal(p$xAxis[[1]]$name, 'mpg')
+  
+  ds <- mtcars |> dplyr::select(cyl, drat) |>
+	ec.data(format='boxplot', jitter=0.1, layout= 'v',
+  			symbolSize=5, itemStyle=list(opacity=0.9), 
+  			emphasis= list(itemStyle= list(color= 'chartreuse', borderWidth=4, opacity=1))
+	)
+  p <- ec.init(
+    #colors= heat.colors(length(mcyl)),
+    legend= list(show= TRUE), tooltip= list(show=TRUE),
+    dataset= ds$dataset, series= ds$series, xAxis= ds$xAxis, yAxis= ds$yAxis
+  ) |> 
+  ec.upd({ 
+  	series[[1]] <- c(series[[1]], 
+  	                 list(color= 'LightGrey', itemStyle= list(color='DimGray')))
+  }) |> ec.theme('dark-mushroom')
+  expect_equal(p$x$opts$series[[1]]$name, 'boxplot')
+  expect_equal(p$x$opts$series[[4]]$name, '8')
+  expect_match(p$x$opts$series[[4]]$tooltip$formatter, "x[1] ); return c;}", fixed=TRUE)
+  expect_equal(p$x$opts$yAxis[[1]]$name, 'drat')
+  expect_equal(p$x$opts$xAxis[[2]]$max, 3)
+
+  # with grouping
+  ds <- airquality |> dplyr::mutate(Day=round(Day/10)) |> 
+    dplyr::relocate(Day,Wind,Month) |> dplyr::group_by(Month) |> 
+  	ec.data(format='boxplot', jitter=0.1)
+  p <- ec.init(
+    dataset= ds$dataset, series= ds$series,xAxis= ds$xAxis, yAxis= ds$yAxis,
+    legend= list(show= TRUE), tooltip= list(show=TRUE)
+  )
+  expect_equal(length(p$x$opts$dataset), 10)
+  expect_equal(p$x$opts$series[[5]]$type, 'boxplot')
+  expect_equal(p$x$opts$series[[5]]$datasetIndex, 9)
+  expect_equal(p$x$opts$series[[6]]$type, 'scatter')
+  expect_equal(p$x$opts$series[[6]]$name, '0')
+  expect_equal(p$x$opts$yAxis[[1]]$type, 'category')
 })
 
-test_that("ec.data for treePC", {
+test_that("ec.data treePC", {
   df <- as.data.frame(Titanic) |> group_by(Survived,Class) |> 
     summarise(value=sum(Freq), .groups='drop') |>
     mutate(parents= as.character(Survived), 
@@ -119,7 +165,7 @@ test_that("ec.data for treePC", {
   expect_equal(length(p$x$opts$series[[1]]$data[[1]]$children), 4)
 })
 
-test_that("ec.data format treeTK", {
+test_that("ec.data treeTK", {
 
   df <- as.data.frame(Titanic) |> 
     group_by(Survived,Age,Sex,Class) |> 
@@ -160,5 +206,9 @@ test_that("load 3D surface", {
   #else expect_equal(1,1)
 })
 
-
+test_that("ec.inspect", {
+  p <- mtcars |> dplyr::group_by(gear) |> ec.init() |> ec.inspect('data')
+  expect_match(p[1], "rows= 33", fixed=TRUE)
+  expect_match(p[2], "filter", fixed=TRUE)
+})
 
